# -*- coding: utf8 -*-
# author: Ludwig Reiter

from sqlalchemy import event
from euhu.esf import to_esf
from euhu.programs.qe import to_bmas, validate
from efa.model.participant import Participant, \
    generate_determine_reportable_function, listener_adapter
from ringo_bmasreport.reports.durchfuehrungsbericht import (
    indicators, recipe
)


program = "qe"


indicators['RI'].append(('C1.1', u'Teilnehmer/-innen, die erfolgreich eine Qualifizierung zur/m staatlich anerkannten Erzieher/-in abgeschlossen haben (C1.1)'))


def derive_indicators(values):
    eu = to_esf(to_bmas(values))
    # Due to changes regarding the working status of participants
    # all participants have a status of CO05, if they had any valid
    # status at all.
    # Details see: https://support.intevation.de/waskiq/issue3436
    if eu.esf.get('CO01') or eu.esf.get('CO03') or eu.esf.get('CO05'):
        eu.esf['CO01'] = False
        eu.esf['CO02'] = False
        eu.esf['CO03'] = False
        eu.esf['CO04'] = False
        eu.esf['CO05'] = True
    return eu.esf


td_update_listener = listener_adapter(
    generate_determine_reportable_function(derive_indicators,
                                           recipe,
                                           validate,
                                           program))

event.listen(Participant, 'after_update', td_update_listener)
